This crate contains kube-rs compatible bindings for Kubernetes custom resources for the kustomize.toolkit.fluxcd.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
kustomize.toolkit.fluxcd.io/v1
Kustomization
kustomize.toolkit.fluxcd.io/v1beta1
Kustomization
kustomize.toolkit.fluxcd.io/v1beta2
Kustomization